_`umbra.ui.widgets.active_QLabel`
=================================

.. automodule:: umbra.ui.widgets.active_QLabel

Module Attributes
-----------------

.. attribute:: umbra.ui.widgets.active_QLabel.LOGGER

Classes
-------

.. autoclass:: Active_QLabel
	:show-inheritance:
	:members:

